@@ -14,8 +14,6 @@
  * to easily construct yacc-compatible scanners.
  * ----------------------------------------------------------------------------- */
 
-char cvsroot_scanner_c[] = "$Id: scanner.c 13976 2012-12-16 13:56:50Z wsfulton $";
-
 #include "swig.h"
 #include <ctype.h>
 
@@ -1143,7 +1141,7 @@ void Scanner_skip_line(Scanner * s) {
     if ((c = nextchar(s)) == 0)
       return;
     if (c == '\\') {
-      c = nextchar(s);
+      nextchar(s);
     } else if (c == '\n') {
       done = 1;
     }
